%define _disable_ld_no_undefined 1

%define shortname indi
%define srcname   lib%{shortname}


Summary:        Library to control astronomical devices
Name:           indilib
Version:        1.9.9
Release:        %mkrel 1
License:        LGPLv2
Group:          System/Libraries
Url:            https://www.indilib.org/
Source0:        https://github.com/indilib/indi/archive/v%{version}/%{shortname}-%{version}.tar.xz

BuildRequires:  cmake
BuildRequires:  libfli-devel
BuildRequires:  libnova-devel
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libusb)
BuildRequires:  pkgconfig(cfitsio) >= 3.090
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(libev)

Provides:       indi = %{version}-%{release}

%description
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

%files
%{_bindir}/*
%{_datadir}/%{shortname}/
%{_libdir}/%{shortname}/
%{_udevrulesdir}/80-*.rules
%{_udevrulesdir}/99-*.rules

#--------------------------------------------------------------------

%define major 1
%define libname %mklibname %{shortname} %major

%package -n     %{libname}
Summary:        Library files for INDI
Group:          System/Libraries

%description -n %{libname}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains library files of indilib.

%files -n %{libname}
%{_libdir}/*.so.%{major}*

#--------------------------------------------------------------------

%define develname %mklibname %{shortname} -d

%package -n     %{develname}
Summary:        INDI development files
Group:          Development/Libraries
Requires:       %{libname} = %{version}-%{release}
Provides:       indi-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains files needed to build applications using indilib.

%files -n %{develname}
%{_libdir}/*.so
%{_libdir}/pkgconfig/libindi.pc
%{_includedir}/%{srcname}/

#--------------------------------------------------------------------
# (lm) libindiclient is built as static only
# libindiclient BR by kstars

%define staticname %mklibname indiclient -s -d

%package -n     %{staticname}
Summary:        INDI indiclient static development file
Group:          Development/Libraries
Requires:       %{develname} = %{version}-%{release}
Provides:       indiclient-static-devel = %{version}-%{release}

%description -n %{staticname}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains libindiclient static file needed to build applications
using indiclient.

%files -n %{staticname}
%{_libdir}/libindiclient.a

#--------------------------------------------------------------------

%prep
%setup -q -n %{shortname}-%{version}
%apply_patches

%build
# This package tries to mix and match PIE and PIC which is wrong and will
# trigger link errors when LTO is enabled.
# Disable LTO
%define _lto_cflags %{nil}

%cmake  \
	-DUDEVRULES_INSTALL_DIR=%{_udevrulesdir} \
	-DINDI_BUILD_QT5_CLIENT=ON \
	-DLIBEV_INCLUDE_DIR=%{_includedir}/libev
%cmake_build

%install
%cmake_install

%__mkdir_p %{buildroot}%{_libdir}/indi/MathPlugins/
mv %{buildroot}%{_prefix}%{_libdir}/indi/MathPlugins/libindi_SVD_MathPlugin.so %{buildroot}%{_libdir}/indi/MathPlugins/libindi_SVD_MathPlugin.so
mv %{buildroot}%{_prefix}%{_libdir}/indi/MathPlugins/libindi_Nearest_MathPlugin.so %{buildroot}%{_libdir}/indi/MathPlugins/libindi_Nearest_MathPlugin.so

find %{buildroot} \( -name "*.a" ! -name "libindiclient.a" \) -delete


%changelog
* Tue Jan 02 2022 tex - 1.9.9-1pclos2022
- new version
